@@ -48,14 +48,16 @@ def run_unit_tests() -> None:
     # Run pytest in another process to ensure that the workspace is and stays
     # clean, and all Matplotlib windows are closed correctly after the tests.
     print('Running unit tests...')
+
     cwd = os.getcwd()
     os.chdir(kineticstoolkit.config.root_folder + '/tests')
     subprocess.call(['coverage', 'run',
                      '--source', '../kineticstoolkit',
                      '--omit', '../kineticstoolkit/dev.py',
                      '--omit', '../kineticstoolkit/cmdgui.py',
-                     '-m', 'pytest', '--ignore=interactive'])
-    subprocess.call(['coverage', 'html'])
+                     '-m', 'pytest', '--ignore=interactive'],
+                    env=kineticstoolkit.config.env)
+    subprocess.call(['coverage', 'html'], env=kineticstoolkit.config.env)
     webbrowser.open_new_tab(
         'file://' + kineticstoolkit.config.root_folder +
         '/tests/htmlcov/index.html')
@@ -70,7 +72,8 @@ def run_static_type_checker() -> None:
     cwd = os.getcwd()
     os.chdir(kineticstoolkit.config.root_folder)
     subprocess.call(['mypy', '--ignore-missing-imports', '-p',
-                     'kineticstoolkit'])
+                     'kineticstoolkit'],
+                    env=kineticstoolkit.config.env)
     os.chdir(cwd)
 
 
@@ -95,7 +98,8 @@ def _generate_tutorial(file: str) -> None:
     print(file)
     subprocess.call(['jupyter-nbconvert', '--execute',
                      '--log-level', 'WARN', '--inplace',
-                     '--to', 'notebook', file])
+                     '--to', 'notebook', file],
+                    env=kineticstoolkit.config.env)
 
     # Remove execution metadata (which changes after each run and pollutes
     # the git repository)
@@ -116,14 +120,29 @@ def build_tutorials() -> None:
     cwd = os.getcwd()
 
     # Run notebooks to generate the tutorials
-    os.chdir(kineticstoolkit.config.root_folder + '/doc')
-    files = [file for file in os.listdir() if file.endswith('.ipynb')]
+#    os.chdir(kineticstoolkit.config.root_folder + '/doc')
+
+    files = []
+
+    for (dirpath, dirnames, filenames) in os.walk(
+            kineticstoolkit.config.root_folder + '/doc'):
+
+        parent_dir = os.path.basename(dirpath)
+
+        if '_build' not in dirpath and not parent_dir.startswith('.'):
+
+            for file in filenames:
+
+                if file.endswith('.ipynb'):
+                    files.append(dirpath + '/' + file)
+
     with multiprocessing.Pool() as pool:
         pool.map(_generate_tutorial, files)
 
-    os.chdir(cwd)
+#    os.chdir(cwd)
     print(f'Done in {time.time() - now} seconds.')
 
+
 def build_website(clean: bool = False) -> None:
     """
     Build the website using sphinx.
@@ -135,19 +154,20 @@ def build_website(clean: bool = False) -> None:
     os.chdir(kineticstoolkit.config.root_folder + '/doc')
 
     if clean:
-        subprocess.call(['make', 'clean'])
+        subprocess.call(['make', 'clean'], env=kineticstoolkit.config.env)
 
     # Generate API
     print('Generating API...')
     os.environ['SPHINX_APIDOC_OPTIONS'] = \
         'members,undoc-members,autosummary'
     subprocess.call(['sphinx-apidoc', '-q', '-e', '-f', '-d', '3',
-                      '-o', 'api', '../kineticstoolkit', 'external',
-                      'kineticstoolkit.cmdgui'])
+                      '-o', 'api', '../kineticstoolkit',
+                      'external'],
+                    env=kineticstoolkit.config.env)
 
     # Generate site
     print('Generating site...')
-    subprocess.call(['make', 'html'])
+    subprocess.call(['make', 'html'], env=kineticstoolkit.config.env)
 
     # Open site
     webbrowser.open_new_tab(
@@ -156,29 +176,15 @@ def build_website(clean: bool = False) -> None:
 
 
 def clean() -> None:
-    """Delete temporary files that were used by the release process."""
-    cwd = os.getcwd()
-
-    # Clean /doc folder
-    os.chdir(kineticstoolkit.config.root_folder + '/doc')
-
-    files = os.listdir()
-    for file in files:
-
-        # Remove all .md files that have a corresponding .ipynb file (since
-        # they were generated from the .ipynb).
-        if (file.endswith('.md') and
-            (file[0:-len('.md')] + '.ipynb') in files):
-            print(f'Removing doc/{file}.')
-            os.remove(file)
-
-        # Remove _files folder, since they are required by the site's html
-        # files but not by the source md and ipynb
-        elif file.endswith('_files') or file == 'api':
-            print(f'Removing doc/{file}.')
-            shutil.rmtree(file)
-
-    os.chdir(cwd)
+    """Remove outputs in jupyter notebooks (before committing to git)."""
+    for (folder, _, files) in os.walk(kineticstoolkit.config.root_folder + '/doc'):
+        if any(['.ipynb' in file for file in files]):
+            subprocess.call(['jupyter-nbconvert',
+                             '--ClearOutputPreprocessor.enabled=True',
+                             '--log-level', 'WARN',
+                             '--inplace',
+                             f'{folder}/*.ipynb'],
+                            env=kineticstoolkit.config.env)
 
 
 def compile_for_pypi() -> None:
@@ -188,7 +194,8 @@ def compile_for_pypi() -> None:
     shutil.rmtree(kineticstoolkit.config.root_folder + '/build',
                   ignore_errors=True)
     os.chdir(kineticstoolkit.config.root_folder)
-    subprocess.call(['python', 'setup.py', 'sdist', 'bdist_wheel'])
+    subprocess.call(['python', 'setup.py', 'sdist', 'bdist_wheel'],
+                    env=kineticstoolkit.config.env)
 
 
 def upload_to_pypi() -> None:
@@ -198,7 +205,8 @@ def upload_to_pypi() -> None:
         'osascript',
         '-e',
         'tell application "Terminal" to do script '
-        f'"conda activate ktk; cd {root_folder}; twine upload dist/*"'])
+        f'"conda activate ktk; cd {root_folder}; twine upload dist/*"'],
+        env=kineticstoolkit.config.env)
 
 
 def release() -> None:
